@@ -203,13 +203,20 @@ runImpalaQuery <- function(query, username, password){
   data_lines <- gsub("^.|.$", "", data_lines)
   split_data_lines <- strsplit(data_lines, '|', fixed=TRUE)
   trimmed_data_lines <- lapply(split_data_lines, trimws)
+  if(length(trimmed_data_lines) > 1024) {
+    extra_pages_number <- length(trimmed_data_lines) %/% 1024
+    repeated_header_lines <- sequence(nvec=rep(4, extra_pages_number), 
+                                      from=(1:extra_pages_number)*1024 + 1
+                                            + seq(from=0, by=4, length=extra_pages_number))
+    trimmed_data_lines <- trimmed_data_lines[-repeated_header_lines]
+  }
   data_matrix <- matrix(unlist(trimmed_data_lines), ncol=length(columnNames), byrow=TRUE)
   colnames(data_matrix) <- columnNames
   ssh_disconnect(session)
   return(data_matrix)
 }
 
-generateEnclosingAirspace <- function(elements, groupingFunction){
-  
-  
-}
\ No newline at end of file
+# generateEnclosingAirspace <- function(elements, groupingFunction){ TODO
+#   
+#   
+# }
\ No newline at end of file
